{
****************************************************************
*  Name    : 18F26Q84                                          *
*  Author  : Jerry Messina                                     *
*  Notice  : Copyright (c) 2020 Mecanique                      *
*          : All Rights Reserved                               *
*  Date    : 06 MAY 2023                                       *
*  RefInfo : mpasm 5.90 (.info v1.60)                          *
* HAND EDITED to remove config and define special #variables   *
*  5/2/2022 - correct memory, add JTAGEN = OFF, MVECEN = OFF   *
****************************************************************
}
module SystemTypes

// system header...
#const _core = $0012                   // processor core
#define _xv18 = 1                      // 18XV core
#variable _maxrom = $010000            // 64KB of program ROM
#define _ram_banks = $20               // 32 RAM bank(s) used
#variable _maxram = $2500-$500         // 8192 bytes of user RAM
#variable _ram_start = $0500           // user RAM start address
#variable _ram_end = $24FF             // user RAM end address
#define _maxaccess = $60               // 96 byte access bank size
#define _accessbank_start = $0500      // access bank start address
#define _accessbank_end = $055F        // access bank end address
#define _access_sfr_start = $0460      // access SFR start address
#define _access_sfr_end = $04FF        // access SFR end address
#define _accessbank = $05              // access bank no
#define _eeprom = $0400                // 1024 bytes of EEPROM
#define _eeprom_start = $380000        // EEPROM start address
#define _eeprom_end = $3803FF          // EEPROM end address
#define _nvmcon = 3                    // eeprom uses NVMCON0/1
#define _nvm_bufferram_start = $2500   // nvm buffer ram start address
#define _nvm_bufferram_end = $25FF     // nvm buffer ram end address
#define _can_ram_start = $2600         // CAN ram start address
#define _can_ram_end = $2DFF           // CAN ram end address
#define _idlocs = 64                   // userID bytes
#define _idlocs_start = $200000        // userID start address
#define _idlocs_end = $20003F          // userID end address
#define _hwstackdepth = 127            // stack depth
#option _hwstackreg = PCON0            // STKUNF/STKOVF register
#const _ports = $04                    // 4 available ports
#const _pps = $01                      // PPS module available
#const _ccp = $03                      // 3 CCP module(s) available
#const _eccp = $00                     // ECCP module NOT supported
#const _timer8 = $03                   // 3 8-bit timers (TMR2/4/6)
#const _timer16 = $03                  // 3 16-bit timers (TMR1/3/5)
#const _mssp = $00                     // MSSP module NOT supported
#const _i2c = $01                      // 1 I2C module(s) available
#const _spi = $02                      // 2 SPI module(s) available
#const _usart = $05                    // 5 USART(s) available
#define _adc2 = 1                      // ADC2 module available
#const _adc = $00                      // 0 ADC channels available
#const _adres = $0A                    // 10 bit ADC resolution
#const _comparator = $02               // 2 comparator(s) available
#const _clc = 08                       // 8 CLC module(s) available
#const _dma = $08                      // 8 DMA channel(s) available
#const _psp = $00                      // Parallel Slave Port (PSP) is NOT supported
#const _can = $01                      // onboard CAN available
#const _usb = $00                      // USB is NOT supported
#const _ethernet = $00                 // onboard Ethernet is NOT supported
#const _flash_write = $01              // FLASH has write capability
#const _wdt_type = $04                 // WDTE watchdog
#define _ipen_type = 2                 // IPEN located in INTCON0
#define _IPEN = INTCON0.5              // IPEN bit definition

// start of system ram (access bank)
#option org_ram = $0500                

// interrupt vectors
#define _intvectors = 128              // interrupt vector table entries
public const
   IRQ_SWINT = 0,                         // irq 0 - Software Interrupt
   IRQ_HLVD = 1,                          // irq 1 - HLVD Interrupt
   IRQ_OSF = 2,                           // irq 2 - Oscillator Failure Interrupt
   IRQ_CSW = 3,                           // irq 3 - Clock Switch Interrupt
   IRQ_TU1 = 4,                           // irq 4 - Universal Timer 1 Interrupt
   IRQ_CLC1 = 5,                          // irq 5 - CLC1 Interrupt
   IRQ_CAN = 6,                           // irq 6 - CAN FD Interrupt
   IRQ_IOC = 7,                           // irq 7 - Interrupt on change
   IRQ_INT0 = 8,                          // irq 8 - External Interrupt 0
   IRQ_ZCD = 9,                           // irq 9 - ZCD Interrupt
   IRQ_AD = 10,                           // irq 10 - ADC Interrupt
   IRQ_ACT = 11,                          // irq 11 - ADC Treshold Interrupt
   IRQ_CM1 = 12,                          // irq 12 - Comparator 1 Interrupt
   IRQ_SMT1 = 13,                         // irq 13 - SMT1 Interrupt
   IRQ_SMT1PRA = 14,                      // irq 14 - 
   IRQ_SMT1PWA = 15,                      // irq 15 - 
   IRQ_ADCH1 = 16,                        // irq 16 - ADC Threshold Interrupt-Context 0
   IRQ_ADCH2 = 17,                        // irq 17 - ADC Threshold Interrupt-Context 1
   IRQ_ADCH3 = 18,                        // irq 18 - ADC Threshold Interrupt-Context 2
   IRQ_ADCH4 = 19,                        // irq 19 - ADC Threshold Interrupt-Context 3
   IRQ_DMA1SCNT = 20,                     // irq 20 - DMA1 Source count Interrupt
   IRQ_DMA1DCNT = 21,                     // irq 21 - DMA1 Destination count Interrupt
   IRQ_DMA1OR = 22,                       // irq 22 - DMA1 Overflow Interrupt
   IRQ_DMA1A = 23,                        // irq 23 - DMA1 Abort Interrupt
   IRQ_SPI1RX = 24,                       // irq 24 - SPI1 Receive Interrupt
   IRQ_SPI1TX = 25,                       // irq 25 - SPI1 Transmit Interrupt
   IRQ_SPI1 = 26,                         // irq 26 - SPI1 Interrupt
   IRQ_TMR2 = 27,                         // irq 27 - Timer 2 Interrupt
   IRQ_TMR1 = 28,                         // irq 28 - Timer 1 Interrupt
   IRQ_TMR1G = 29,                        // irq 29 - Timer 1 Gate Interrupt
   IRQ_CCP1 = 30,                         // irq 30 - CCP1 Interrupt
   IRQ_TMR0 = 31,                         // irq 31 - Timer0 Interrupt
   IRQ_U1RX = 32,                         // irq 32 - UART1 Receive Interrupt
   IRQ_U1TX = 33,                         // irq 33 - UART1 Transmit Interrupt
   IRQ_U1E = 34,                          // irq 34 - UART1 Error Interrupt
   IRQ_U1 = 35,                           // irq 35 - UART1 Interrupt
   IRQ_CANRX = 36,                        // irq 36 - CAN FD Receive Interrupt
   IRQ_CANTX = 37,                        // irq 37 - CAN FD Transmit Interrupt
   IRQ_PWM1PR = 38,                       // irq 38 - PWM1 Period Interrupt
   IRQ_PWM1 = 39,                         // irq 39 - PWM1 Interrupt
   IRQ_SPI2RX = 40,                       // irq 40 - SPI2 Receive Interrupt
   IRQ_SPI2TX = 41,                       // irq 41 - SPI2 Transmit Interrupt
   IRQ_SPI2 = 42,                         // irq 42 - SPI 2 Interrupt
   IRQ_TU2 = 43,                          // irq 43 - Universal Time 2 Interrupt
   IRQ_TMR3 = 44,                         // irq 44 - Timer 3 Interrupt
   IRQ_TMR3G = 45,                        // irq 45 - Timer 3 Gate Interrupt
   IRQ_PWM2PR = 46,                       // irq 46 - PWM2 Period Interrupt
   IRQ_PWM2 = 47,                         // irq 47 - PWM2 Interrupt
   IRQ_INT1 = 48,                         // irq 48 - External Interrupt 1
   IRQ_CLC2 = 49,                         // irq 49 - CLC2 Interrupt
   IRQ_CWG1 = 50,                         // irq 50 - CWG 1 Interrupt
   IRQ_NCO1 = 51,                         // irq 51 - NCO 1 Interrupt
   IRQ_DMA2SCNT = 52,                     // irq 52 - DMA2 Source Count Interrupt
   IRQ_DMA2DCNT = 53,                     // irq 53 - DMA2 Destination Count Interrupt
   IRQ_DMA2OR = 54,                       // irq 54 - DMA2 Overflow Interrupt
   IRQ_DMA2A = 55,                        // irq 55 - DMA2 Abort Interrupt
   IRQ_I2C1RX = 56,                       // irq 56 - I2C1 Receive Interrupt
   IRQ_I2C1TX = 57,                       // irq 57 - I2C1 Transmit Interrupt
   IRQ_I2C1 = 58,                         // irq 58 - I2C1 General Interrupt
   IRQ_I2C1E = 59,                        // irq 59 - I2C1 Error Interrupt
   IRQ_CLC3 = 61,                         // irq 61 - CLC3 Interrupt
   IRQ_PWM3PR = 62,                       // irq 62 - PWM3 Period Interrupt
   IRQ_PWM3 = 63,                         // irq 63 - PWM3 Interrupt
   IRQ_U2RX = 64,                         // irq 64 - UART2 Receive Interrupt
   IRQ_U2TX = 65,                         // irq 65 - UART2 Transmit Interrupt
   IRQ_U2E = 66,                          // irq 66 - UART2 Error Interrupt
   IRQ_U2 = 67,                           // irq 67 - UART2 Interrupt
   IRQ_TMR5 = 68,                         // irq 68 - Timer5 Interrupt
   IRQ_TMR5G = 69,                        // irq 69 - Timer5 Gate Interrupt
   IRQ_CCP2 = 70,                         // irq 70 - CCP2 Interrupt
   IRQ_SCAN = 71,                         // irq 71 - Scanner Interrupt
   IRQ_U3RX = 72,                         // irq 72 - UART3 Receive Interrupt
   IRQ_U3TX = 73,                         // irq 73 - UART3 Transmit Interrupt
   IRQ_U3E = 74,                          // irq 74 - UART3 Error Interrupt
   IRQ_U3 = 75,                           // irq 75 - UART3 Interrupt
   IRQ_CLC4 = 77,                         // irq 77 - CLC4 Interrupt
   IRQ_PWM4PR = 78,                       // irq 78 - PWM4 Period Interrupt
   IRQ_PWM4 = 79,                         // irq 79 - PWM4 Interrupt
   IRQ_INT2 = 80,                         // irq 80 - External Interrupt 2
   IRQ_CLC5 = 81,                         // irq 81 - CLC5 Interrupt
   IRQ_CWG2 = 82,                         // irq 82 - CWG2 Interrupt
   IRQ_NCO2 = 83,                         // irq 83 - NCO2 Interrupt
   IRQ_DMA3SCNT = 84,                     // irq 84 - DMA3 Source count Interrupt
   IRQ_DMA3DCNT = 85,                     // irq 85 - DMA3 Destination count Interrupt
   IRQ_DMA3OR = 86,                       // irq 86 - DMA3 Overflow Interrupt
   IRQ_DMA3A = 87,                        // irq 87 - DMA3 Abort Interrupt
   IRQ_CCP3 = 88,                         // irq 88 - CCP3 Interrupt
   IRQ_CLC6 = 89,                         // irq 89 - CLC6 Interrupt
   IRQ_CWG3 = 90,                         // irq 90 - CWG3 Interrupt
   IRQ_TMR4 = 91,                         // irq 91 - TMR4 Interrupt
   IRQ_DMA4SCNT = 92,                     // irq 92 - DMA4 Source count Interrupt
   IRQ_DMA4DCNT = 93,                     // irq 93 - DMA4 Destination count Interrupt
   IRQ_DMA4OR = 94,                       // irq 94 - DMA4 Overflow Interrupt
   IRQ_DMA4A = 95,                        // irq 95 - DMA4 Abort Interrupt
   IRQ_U4RX = 96,                         // irq 96 - UART2 Receive Interrupt
   IRQ_U4TX = 97,                         // irq 97 - UART 4 Transmit Interrupt
   IRQ_U4E = 98,                          // irq 98 - UART4 Error Interrupt
   IRQ_U4 = 99,                           // irq 99 - UART4 Interrupt
   IRQ_DMA5SCNT = 100,                    // irq 100 - DMA5 Source Count Interrupt
   IRQ_DMA5DCNT = 101,                    // irq 101 - DMA5 Destination Count Interrupt
   IRQ_DMA5OR = 102,                      // irq 102 - DMA5 Overflow Interrupt
   IRQ_DMA5A = 103,                       // irq 103 - DMA5 Abort Interrupt
   IRQ_U5RX = 104,                        // irq 104 - UART5 Receive Interrupt
   IRQ_U5TX = 105,                        // irq 105 - UART5 Transmit Interrupt
   IRQ_U5E = 106,                         // irq 106 - UART5 Error Interrupt
   IRQ_U5 = 107,                          // irq 107 - UART5 Interrupt
   IRQ_DMA6SCNT = 108,                    // irq 108 - DMA6 Source Count Interrupt
   IRQ_DMA6DCNT = 109,                    // irq 109 - DMA6 Destination Count Interrupt
   IRQ_DMA6OR = 110,                      // irq 110 - DMA6 Overflow Interrupt
   IRQ_DMA6A = 111,                       // irq 111 - DMA6 Abort Interrupt
   IRQ_CLC7 = 113,                        // irq 113 - CLC7 Interrupt
   IRQ_CM2 = 114,                         // irq 114 - Comparator 2 Interrupt
   IRQ_NCO3 = 115,                        // irq 115 - NCO3 Interrupt
   IRQ_DMA7SCNT = 116,                    // irq 116 - DMA7 Source Count Interrupt
   IRQ_DMA7DCNT = 117,                    // irq 117 - DMA7 Destination Count Interrupt
   IRQ_DMA7OR = 118,                      // irq 118 - DMA7 Overflow Interrupt
   IRQ_DMA7A = 119,                       // irq 119 - DMA7 Abort Interrupt
   IRQ_NVM = 120,                         // irq 120 - NVM Interrupt
   IRQ_CLC8 = 121,                        // irq 121 - CLC8 Interrupt
   IRQ_CRC = 122,                         // irq 122 - CRC Interrupt
   IRQ_TMR6 = 123,                        // irq 123 - TMR6 Interrupt
   IRQ_DMA8SCNT = 124,                    // irq 124 - DMA8 Source Count Interrupt
   IRQ_DMA8DCNT = 125,                    // irq 125 - DMA8 Destination Count Interrupt
   IRQ_DMA8OR = 126,                      // irq 126 - DMA8 Overflow Interrupt
   IRQ_DMA8A = 127                        // irq 127 - DMA8 Abort Interrupt

// special function registers...
public system
   BOOTREG as byte absolute $0038,
   CLKRCON as byte absolute $0039,
   CLKRCLK as byte absolute $003A,
   NVMCON0 as byte absolute $0040,
   NVMCON1 as byte absolute $0041,
   NVMLOCK as byte absolute $0042,
   NVMADR as byte absolute $0043,
   NVMADRL as byte absolute $0043,
   NVMADRH as byte absolute $0044,
   NVMADRU as byte absolute $0045,
   NVMDAT as byte absolute $0046,
   NVMDATL as byte absolute $0046,
   NVMDATH as byte absolute $0047,
   VREGCON as byte absolute $0048,
   BORCON as byte absolute $0049,
   HLVDCON0 as byte absolute $004A,
   HLVDCON1 as byte absolute $004B,
   ZCDCON as byte absolute $004C,
   PMD0 as byte absolute $0060,
   PMD1 as byte absolute $0061,
   PMD2 as byte absolute $0062,
   PMD3 as byte absolute $0063,
   PMD4 as byte absolute $0064,
   PMD5 as byte absolute $0065,
   PMD6 as byte absolute $0066,
   PMD7 as byte absolute $0067,
   PMD8 as byte absolute $0068,
   MD1CON0 as byte absolute $006A,
   MD1CON1 as byte absolute $006B,
   MD1SRC as byte absolute $006C,
   MD1CARL as byte absolute $006D,
   MD1CARH as byte absolute $006E,
   CMOUT as byte absolute $006F,
   CM1CON0 as byte absolute $0070,
   CM1CON1 as byte absolute $0071,
   CM1NCH as byte absolute $0072,
   CM1PCH as byte absolute $0073,
   CM2CON0 as byte absolute $0074,
   CM2CON1 as byte absolute $0075,
   CM2NCH as byte absolute $0076,
   CM2PCH as byte absolute $0077,
   WDTCON0 as byte absolute $0078,
   WDTCON1 as byte absolute $0079,
   WDTPSL as byte absolute $007A,
   WDTPSH as byte absolute $007B,
   WDTTMR as byte absolute $007C,
   DAC1DAT as byte absolute $007D,
   DAC1DATL as byte absolute $007D,
   DAC1CON as byte absolute $007F,
   SPI1RXB as byte absolute $0080,
   SPI1TXB as byte absolute $0081,
   SPI1TCNT as byte absolute $0082,
   SPI1TCNTL as byte absolute $0082,
   SPI1TCNTH as byte absolute $0083,
   SPI1CON0 as byte absolute $0084,
   SPI1CON1 as byte absolute $0085,
   SPI1CON2 as byte absolute $0086,
   SPI1STATUS as byte absolute $0087,
   SPI1TWIDTH as byte absolute $0088,
   SPI1BAUD as byte absolute $0089,
   SPI1INTF as byte absolute $008A,
   SPI1INTE as byte absolute $008B,
   SPI1CLK as byte absolute $008C,
   SPI2RXB as byte absolute $008D,
   SPI2TXB as byte absolute $008E,
   SPI2TCNT as byte absolute $008F,
   SPI2TCNTL as byte absolute $008F,
   SPI2TCNTH as byte absolute $0090,
   SPI2CON0 as byte absolute $0091,
   SPI2CON1 as byte absolute $0092,
   SPI2CON2 as byte absolute $0093,
   SPI2STATUS as byte absolute $0094,
   SPI2TWIDTH as byte absolute $0095,
   SPI2BAUD as byte absolute $0096,
   SPI2INTF as byte absolute $0097,
   SPI2INTE as byte absolute $0098,
   SPI2CLK as byte absolute $0099,
   ACTCON as byte absolute $00AC,
   OSCCON1 as byte absolute $00AD,
   OSCCON2 as byte absolute $00AE,
   OSCCON3 as byte absolute $00AF,
   OSCTUNE as byte absolute $00B0,
   OSCFREQ as byte absolute $00B1,
   OSCFRQ as byte absolute $00B1,
   OSCSTAT as byte absolute $00B2,
   OSCSTAT1 as byte absolute $00B2,
   OSCEN as byte absolute $00B3,
   PRLOCK as byte absolute $00B4,
   SCANPR as byte absolute $00B5,
   DMA1PR as byte absolute $00B6,
   DMA2PR as byte absolute $00B7,
   DMA3PR as byte absolute $00B8,
   DMA4PR as byte absolute $00B9,
   DMA5PR as byte absolute $00BA,
   DMA6PR as byte absolute $00BB,
   DMA7PR as byte absolute $00BC,
   DMA8PR as byte absolute $00BD,
   MAINPR as byte absolute $00BE,
   ISRPR as byte absolute $00BF,
   CLCDATA as byte absolute $00D4,
   CLCSELECT as byte absolute $00D5,
   CLCNCON as byte absolute $00D6,
   CLCNPOL as byte absolute $00D7,
   CLCNSEL0 as byte absolute $00D8,
   CLCNSEL1 as byte absolute $00D9,
   CLCNSEL2 as byte absolute $00DA,
   CLCNSEL3 as byte absolute $00DB,
   CLCNGLS0 as byte absolute $00DC,
   CLCNGLS1 as byte absolute $00DD,
   CLCNGLS2 as byte absolute $00DE,
   CLCNGLS3 as byte absolute $00DF,
   DMASELECT as byte absolute $00E8,
   DMANBUF as byte absolute $00E9,
   DMANDCNT as byte absolute $00EA,
   DMANDCNTL as byte absolute $00EA,
   DMANDCNTH as byte absolute $00EB,
   DMANDPTR as byte absolute $00EC,
   DMANDPTRL as byte absolute $00EC,
   DMANDPTRH as byte absolute $00ED,
   DMANDSZ as byte absolute $00EE,
   DMANDSZL as byte absolute $00EE,
   DMANDSZH as byte absolute $00EF,
   DMANDSA as byte absolute $00F0,
   DMANDSAL as byte absolute $00F0,
   DMANDSAH as byte absolute $00F1,
   DMANSCNT as byte absolute $00F2,
   DMANSCNTL as byte absolute $00F2,
   DMANSCNTH as byte absolute $00F3,
   DMANSPTR as byte absolute $00F4,
   DMANSPTRL as byte absolute $00F4,
   DMANSPTRH as byte absolute $00F5,
   DMANSPTRU as byte absolute $00F6,
   DMANSSZ as byte absolute $00F7,
   DMANSSZL as byte absolute $00F7,
   DMANSSZH as byte absolute $00F8,
   DMANSSA as byte absolute $00F9,
   DMANSSAL as byte absolute $00F9,
   DMANSSAH as byte absolute $00FA,
   DMANSSAU as byte absolute $00FB,
   DMANCON0 as byte absolute $00FC,
   DMANCON1 as byte absolute $00FD,
   DMANAIRQ as byte absolute $00FE,
   DMANSIRQ as byte absolute $00FF,
   C1CONL as byte absolute $0100,
   C1CONH as byte absolute $0101,
   C1CONU as byte absolute $0102,
   C1CONT as byte absolute $0103,
   C1NBTCFGL as byte absolute $0104,
   C1NBTCFGH as byte absolute $0105,
   C1NBTCFGU as byte absolute $0106,
   C1NBTCFGT as byte absolute $0107,
   C1DBTCFGL as byte absolute $0108,
   C1DBTCFGH as byte absolute $0109,
   C1DBTCFGU as byte absolute $010A,
   C1DBTCFGT as byte absolute $010B,
   C1TDCL as byte absolute $010C,
   C1TDCH as byte absolute $010D,
   C1TDCU as byte absolute $010E,
   C1TDCT as byte absolute $010F,
   C1TBC as byte absolute $0110,
   C1TBCL as byte absolute $0110,
   C1TBCH as byte absolute $0111,
   C1TBCU as byte absolute $0112,
   C1TBCT as byte absolute $0113,
   C1TSCONL as byte absolute $0114,
   C1TSCONH as byte absolute $0115,
   C1TSCONU as byte absolute $0116,
   C1TSCONT as byte absolute $0117,
   C1VECL as byte absolute $0118,
   C1VECH as byte absolute $0119,
   C1VECU as byte absolute $011A,
   C1VECT as byte absolute $011B,
   C1INTL as byte absolute $011C,
   C1INTH as byte absolute $011D,
   C1INTU as byte absolute $011E,
   C1INTT as byte absolute $011F,
   C1RXIF as byte absolute $0120,
   C1RXIFL as byte absolute $0120,
   C1RXIFH as byte absolute $0121,
   C1RXIFU as byte absolute $0122,
   C1RXIFT as byte absolute $0123,
   C1TXIF as byte absolute $0124,
   C1TXIFL as byte absolute $0124,
   C1TXIFH as byte absolute $0125,
   C1TXIFU as byte absolute $0126,
   C1TXIFT as byte absolute $0127,
   C1RXOVIF as byte absolute $0128,
   C1RXOVIFL as byte absolute $0128,
   C1RXOVIFH as byte absolute $0129,
   C1RXOVIFU as byte absolute $012A,
   C1RXOVIFT as byte absolute $012B,
   C1TXATIF as byte absolute $012C,
   C1TXATIFL as byte absolute $012C,
   C1TXATIFH as byte absolute $012D,
   C1TXATIFU as byte absolute $012E,
   C1TXATIFT as byte absolute $012F,
   C1TXREQ as byte absolute $0130,
   C1TXREQL as byte absolute $0130,
   C1TXREQH as byte absolute $0131,
   C1TXR as byte absolute $0132,
   C1TXREQT as byte absolute $0133,
   C1TRECL as byte absolute $0134,
   C1TRECH as byte absolute $0135,
   C1TRECU as byte absolute $0136,
   C1TRECT as byte absolute $0137,
   C1BDIAG0L as byte absolute $0138,
   C1BDIAG0H as byte absolute $0139,
   C1BDIAG0U as byte absolute $013A,
   C1BDIAG0T as byte absolute $013B,
   C1BDIAG1L as byte absolute $013C,
   C1BDIAG1H as byte absolute $013D,
   C1BDIAG1U as byte absolute $013E,
   C1BDIAG1T as byte absolute $013F,
   C1TEFCONL as byte absolute $0140,
   C1TEFCONH as byte absolute $0141,
   C1TEFCONU as byte absolute $0142,
   C1TEFCONT as byte absolute $0143,
   C1TEFSTAL as byte absolute $0144,
   C1TEFSTAH as byte absolute $0145,
   C1TEFSTAU as byte absolute $0146,
   C1TEFSTAT as byte absolute $0147,
   C1TEFUA as byte absolute $0148,
   C1TEFUAL as byte absolute $0148,
   C1TEFUAH as byte absolute $0149,
   C1TEFUAU as byte absolute $014A,
   C1TEFUAT as byte absolute $014B,
   C1FIFOBA as byte absolute $014C,
   C1FIFOBAL as byte absolute $014C,
   C1FIFOBAH as byte absolute $014D,
   C1FIFOBAU as byte absolute $014E,
   C1FIFOBAT as byte absolute $014F,
   C1TXQCONL as byte absolute $0150,
   C1TXQCONH as byte absolute $0151,
   C1TXQCONU as byte absolute $0152,
   C1TXQCONT as byte absolute $0153,
   C1TXQSTAL as byte absolute $0154,
   C1TXQSTAH as byte absolute $0155,
   C1TXQSTAU as byte absolute $0156,
   C1TXQSTAT as byte absolute $0157,
   C1TXQUA as byte absolute $0158,
   C1TXQUAL as byte absolute $0158,
   C1TXQUAH as byte absolute $0159,
   C1TXQUAU as byte absolute $015A,
   C1TXQUAT as byte absolute $015B,
   C1FIFOCON1 as byte absolute $015C,
   C1FIFOCON1L as byte absolute $015C,
   C1FIFOCON1H as byte absolute $015D,
   C1FIFOCON1U as byte absolute $015E,
   C1FIFOCON1T as byte absolute $015F,
   C1FIFOSTA1 as byte absolute $0160,
   C1FIFOSTA1L as byte absolute $0160,
   C1FIFOSTA1H as byte absolute $0161,
   C1FIFOSTA1U as byte absolute $0162,
   C1FIFOSTA1T as byte absolute $0163,
   C1FIFOUA1 as byte absolute $0164,
   C1FIFOUA1L as byte absolute $0164,
   C1FIFOUA1H as byte absolute $0165,
   C1FIFOUA1U as byte absolute $0166,
   C1FIFOUA1T as byte absolute $0167,
   C1FIFOCON2 as byte absolute $0168,
   C1FIFOCON2L as byte absolute $0168,
   C1FIFOCON2H as byte absolute $0169,
   C1FIFOCON2U as byte absolute $016A,
   C1FIFOCON2T as byte absolute $016B,
   C1FIFOSTA2 as byte absolute $016C,
   C1FIFOSTA2L as byte absolute $016C,
   C1FIFOSTA2H as byte absolute $016D,
   C1FIFOSTA2U as byte absolute $016E,
   C1FIFOSTA2T as byte absolute $016F,
   C1FIFOUA2 as byte absolute $0170,
   C1FIFOUA2L as byte absolute $0170,
   C1FIFOUA2H as byte absolute $0171,
   C1FIFOUA2U as byte absolute $0172,
   C1FIFOUA2T as byte absolute $0173,
   C1FIFOCON3 as byte absolute $0174,
   C1FIFOCON3L as byte absolute $0174,
   C1FIFOCON3H as byte absolute $0175,
   C1FIFOCON3U as byte absolute $0176,
   C1FIFOCON3T as byte absolute $0177,
   C1FIFOSTA3 as byte absolute $0178,
   C1FIFOSTA3L as byte absolute $0178,
   C1FIFOSTA3H as byte absolute $0179,
   C1FIFOSTA3U as byte absolute $017A,
   C1FIFOSTA3T as byte absolute $017B,
   C1FIFOUA3 as byte absolute $017C,
   C1FIFOUA3L as byte absolute $017C,
   C1FIFOUA3H as byte absolute $017D,
   C1FIFOUA3U as byte absolute $017E,
   C1FIFOUA3T as byte absolute $017F,
   C1FLTCON0L as byte absolute $0180,
   C1FLTCON0H as byte absolute $0181,
   C1FLTCON0U as byte absolute $0182,
   C1FLTCON0T as byte absolute $0183,
   C1FLTCON1L as byte absolute $0184,
   C1FLTCON1H as byte absolute $0185,
   C1FLTCON1U as byte absolute $0186,
   C1FLTCON1T as byte absolute $0187,
   C1FLTCON2L as byte absolute $0188,
   C1FLTCON2H as byte absolute $0189,
   C1FLTCON2U as byte absolute $018A,
   C1FLTCON2T as byte absolute $018B,
   C1FLTOBJ0 as byte absolute $018C,
   C1FLTOBJ0L as byte absolute $018C,
   C1FLTOBJ0H as byte absolute $018D,
   C1FLTOBJ0U as byte absolute $018E,
   C1FLTOBJ0T as byte absolute $018F,
   C1MASK0 as byte absolute $0190,
   C1MASK0L as byte absolute $0190,
   C1MASK0H as byte absolute $0191,
   C1MASK0U as byte absolute $0192,
   C1MASK0T as byte absolute $0193,
   C1FLTOBJ1 as byte absolute $0194,
   C1FLTOBJ1L as byte absolute $0194,
   C1FLTOBJ1H as byte absolute $0195,
   C1FLTOBJ1U as byte absolute $0196,
   C1FLTOBJ1T as byte absolute $0197,
   C1MASK1 as byte absolute $0198,
   C1MASK1L as byte absolute $0198,
   C1MASK1H as byte absolute $0199,
   C1MASK1U as byte absolute $019A,
   C1MASK1T as byte absolute $019B,
   C1FLTOBJ2 as byte absolute $019C,
   C1FLTOBJ2L as byte absolute $019C,
   C1FLTOBJ2H as byte absolute $019D,
   C1FLTOBJ2U as byte absolute $019E,
   C1FLTOBJ2T as byte absolute $019F,
   C1MASK2 as byte absolute $01A0,
   C1MASK2L as byte absolute $01A0,
   C1MASK2H as byte absolute $01A1,
   C1MASK2U as byte absolute $01A2,
   C1MASK2T as byte absolute $01A3,
   C1FLTOBJ3 as byte absolute $01A4,
   C1FLTOBJ3L as byte absolute $01A4,
   C1FLTOBJ3H as byte absolute $01A5,
   C1FLTOBJ3U as byte absolute $01A6,
   C1FLTOBJ3T as byte absolute $01A7,
   C1MASK3 as byte absolute $01A8,
   C1MASK3L as byte absolute $01A8,
   C1MASK3H as byte absolute $01A9,
   C1MASK3U as byte absolute $01AA,
   C1MASK3T as byte absolute $01AB,
   C1FLTOBJ4 as byte absolute $01AC,
   C1FLTOBJ4L as byte absolute $01AC,
   C1FLTOBJ4H as byte absolute $01AD,
   C1FLTOBJ4U as byte absolute $01AE,
   C1FLTOBJ4T as byte absolute $01AF,
   C1MASK4 as byte absolute $01B0,
   C1MASK4L as byte absolute $01B0,
   C1MASK4H as byte absolute $01B1,
   C1MASK4U as byte absolute $01B2,
   C1MASK4T as byte absolute $01B3,
   C1FLTOBJ5 as byte absolute $01B4,
   C1FLTOBJ5L as byte absolute $01B4,
   C1FLTOBJ5H as byte absolute $01B5,
   C1FLTOBJ5U as byte absolute $01B6,
   C1FLTOBJ5T as byte absolute $01B7,
   C1MASK5 as byte absolute $01B8,
   C1MASK5L as byte absolute $01B8,
   C1MASK5H as byte absolute $01B9,
   C1MASK5U as byte absolute $01BA,
   C1MASK5T as byte absolute $01BB,
   C1FLTOBJ6 as byte absolute $01BC,
   C1FLTOBJ6L as byte absolute $01BC,
   C1FLTOBJ6H as byte absolute $01BD,
   C1FLTOBJ6U as byte absolute $01BE,
   C1FLTOBJ6T as byte absolute $01BF,
   C1MASK6 as byte absolute $01C0,
   C1MASK6L as byte absolute $01C0,
   C1MASK6H as byte absolute $01C1,
   C1MASK6U as byte absolute $01C2,
   C1MASK6T as byte absolute $01C3,
   C1FLTOBJ7 as byte absolute $01C4,
   C1FLTOBJ7L as byte absolute $01C4,
   C1FLTOBJ7H as byte absolute $01C5,
   C1FLTOBJ7U as byte absolute $01C6,
   C1FLTOBJ7T as byte absolute $01C7,
   C1MASK7 as byte absolute $01C8,
   C1MASK7L as byte absolute $01C8,
   C1MASK7H as byte absolute $01C9,
   C1MASK7U as byte absolute $01CA,
   C1MASK7T as byte absolute $01CB,
   C1FLTOBJ8 as byte absolute $01CC,
   C1FLTOBJ8L as byte absolute $01CC,
   C1FLTOBJ8H as byte absolute $01CD,
   C1FLTOBJ8U as byte absolute $01CE,
   C1FLTOBJ8T as byte absolute $01CF,
   C1MASK8 as byte absolute $01D0,
   C1MASK8L as byte absolute $01D0,
   C1MASK8H as byte absolute $01D1,
   C1MASK8U as byte absolute $01D2,
   C1MASK8T as byte absolute $01D3,
   C1FLTOBJ9 as byte absolute $01D4,
   C1FLTOBJ9L as byte absolute $01D4,
   C1FLTOBJ9H as byte absolute $01D5,
   C1FLTOBJ9U as byte absolute $01D6,
   C1FLTOBJ9T as byte absolute $01D7,
   C1MASK9 as byte absolute $01D8,
   C1MASK9L as byte absolute $01D8,
   C1MASK9H as byte absolute $01D9,
   C1MASK9U as byte absolute $01DA,
   C1MASK9T as byte absolute $01DB,
   C1FLTOBJ10 as byte absolute $01DC,
   C1FLTOBJ10L as byte absolute $01DC,
   C1FLTOBJ10H as byte absolute $01DD,
   C1FLTOBJ10U as byte absolute $01DE,
   C1FLTOBJ10T as byte absolute $01DF,
   C1MASK10 as byte absolute $01E0,
   C1MASK10L as byte absolute $01E0,
   C1MASK10H as byte absolute $01E1,
   C1MASK10U as byte absolute $01E2,
   C1MASK10T as byte absolute $01E3,
   C1FLTOBJ11 as byte absolute $01E4,
   C1FLTOBJ11L as byte absolute $01E4,
   C1FLTOBJ11H as byte absolute $01E5,
   C1FLTOBJ11U as byte absolute $01E6,
   C1FLTOBJ11T as byte absolute $01E7,
   C1MASK11 as byte absolute $01E8,
   C1MASK11L as byte absolute $01E8,
   C1MASK11H as byte absolute $01E9,
   C1MASK11U as byte absolute $01EA,
   C1MASK11T as byte absolute $01EB,
   PPSLOCK as byte absolute $0200,
   RA0PPS as byte absolute $0201,
   RA1PPS as byte absolute $0202,
   RA2PPS as byte absolute $0203,
   RA3PPS as byte absolute $0204,
   RA4PPS as byte absolute $0205,
   RA5PPS as byte absolute $0206,
   RA6PPS as byte absolute $0207,
   RA7PPS as byte absolute $0208,
   RB0PPS as byte absolute $0209,
   RB1PPS as byte absolute $020A,
   RB2PPS as byte absolute $020B,
   RB3PPS as byte absolute $020C,
   RB4PPS as byte absolute $020D,
   RB5PPS as byte absolute $020E,
   RB6PPS as byte absolute $020F,
   RB7PPS as byte absolute $0210,
   RC0PPS as byte absolute $0211,
   RC1PPS as byte absolute $0212,
   RC2PPS as byte absolute $0213,
   RC3PPS as byte absolute $0214,
   RC4PPS as byte absolute $0215,
   RC5PPS as byte absolute $0216,
   RC6PPS as byte absolute $0217,
   RC7PPS as byte absolute $0218,
   CANRXPPS as byte absolute $023D,
   INT0PPS as byte absolute $023E,
   INT1PPS as byte absolute $023F,
   INT2PPS as byte absolute $0240,
   T0CKIPPS as byte absolute $0241,
   T1CKIPPS as byte absolute $0242,
   T1GPPS as byte absolute $0243,
   T3CKIPPS as byte absolute $0244,
   T3GPPS as byte absolute $0245,
   T5CKIPPS as byte absolute $0246,
   T5GPPS as byte absolute $0247,
   T2INPPS as byte absolute $0248,
   T4INPPS as byte absolute $0249,
   T6INPPS as byte absolute $024A,
   TUIN0PPS as byte absolute $024B,
   TUIN1PPS as byte absolute $024C,
   TUIN2PPS as byte absolute $024D,
   TUIN3PPS as byte absolute $024E,
   CCP1PPS as byte absolute $024F,
   CCP2PPS as byte absolute $0250,
   CCP3PPS as byte absolute $0251,
   PWM1ERSPPS as byte absolute $0253,
   PWM2ERSPPS as byte absolute $0254,
   PWM3ERSPPS as byte absolute $0255,
   PWM4ERSPPS as byte absolute $0256,
   PWMIN0PPS as byte absolute $0257,
   PWMIN1PPS as byte absolute $0258,
   SMT1WINPPS as byte absolute $0259,
   SMT1SIGPPS as byte absolute $025A,
   CWG1INPPS as byte absolute $025B,
   CWG1PPS as byte absolute $025B,
   CWG2INPPS as byte absolute $025C,
   CWG2PPS as byte absolute $025C,
   CWG3INPPS as byte absolute $025D,
   CWG3PPS as byte absolute $025D,
   MD1CARLPPS as byte absolute $025E,
   MDCARLPPS as byte absolute $025E,
   MD1CARHPPS as byte absolute $025F,
   MDCARHPPS as byte absolute $025F,
   MD1SRCPPS as byte absolute $0260,
   MDSRCPPS as byte absolute $0260,
   CLCIN0PPS as byte absolute $0261,
   CLCIN1PPS as byte absolute $0262,
   CLCIN2PPS as byte absolute $0263,
   CLCIN3PPS as byte absolute $0264,
   CLCIN4PPS as byte absolute $0265,
   CLCIN5PPS as byte absolute $0266,
   CLCIN6PPS as byte absolute $0267,
   CLCIN7PPS as byte absolute $0268,
   ADACTPPS as byte absolute $0269,
   SPI1SCKPPS as byte absolute $026A,
   SPI1SDIPPS as byte absolute $026B,
   SPI1SSPPS as byte absolute $026C,
   SPI2SCKPPS as byte absolute $026D,
   SPI2SDIPPS as byte absolute $026E,
   SPI2SSPPS as byte absolute $026F,
   I2C1SDAPPS as byte absolute $0270,
   I2C1SCLPPS as byte absolute $0271,
   U1RXPPS as byte absolute $0272,
   U1CTSPPS as byte absolute $0273,
   U2RXPPS as byte absolute $0274,
   U2CTSPPS as byte absolute $0275,
   U3RXPPS as byte absolute $0276,
   U3CTSPPS as byte absolute $0277,
   U4RXPPS as byte absolute $0278,
   U4CTSPPS as byte absolute $0279,
   U5RXPPS as byte absolute $027A,
   U5CTSPPS as byte absolute $027B,
   RC4I2C as byte absolute $0286,
   RC3I2C as byte absolute $0287,
   RB2I2C as byte absolute $0288,
   RB1I2C as byte absolute $0289,
   I2C1RXB as byte absolute $028A,
   I2C1TXB as byte absolute $028B,
   I2C1CNTL as byte absolute $028C,
   I2C1CNTH as byte absolute $028D,
   I2C1ADB0 as byte absolute $028E,
   I2C1ADB1 as byte absolute $028F,
   I2C1ADR0 as byte absolute $0290,
   I2C1ADR1 as byte absolute $0291,
   I2C1ADR2 as byte absolute $0292,
   I2C1ADR3 as byte absolute $0293,
   I2C1CON0 as byte absolute $0294,
   I2C1CON1 as byte absolute $0295,
   I2C1CON2 as byte absolute $0296,
   I2C1ERR as byte absolute $0297,
   I2C1STAT0 as byte absolute $0298,
   I2C1STAT1 as byte absolute $0299,
   I2C1PIR as byte absolute $029A,
   I2C1PIE as byte absolute $029B,
   I2C1BTO as byte absolute $029C,
   I2C1BAUD as byte absolute $029D,
   I2C1CLK as byte absolute $029E,
   I2C1BTOC as byte absolute $029F,
   U1RXB as byte absolute $02A1,
   U1RXBL as byte absolute $02A1,
   U1RXCHK as byte absolute $02A2,
   U1TXB as byte absolute $02A3,
   U1TXBL as byte absolute $02A3,
   U1TXCHK as byte absolute $02A4,
   U1P1 as byte absolute $02A5,
   U1P1L as byte absolute $02A5,
   U1P1H as byte absolute $02A6,
   U1P2 as byte absolute $02A7,
   U1P2L as byte absolute $02A7,
   U1P2H as byte absolute $02A8,
   U1P3 as byte absolute $02A9,
   U1P3L as byte absolute $02A9,
   U1P3H as byte absolute $02AA,
   U1CON0 as byte absolute $02AB,
   U1CON1 as byte absolute $02AC,
   U1CON2 as byte absolute $02AD,
   U1BRG as byte absolute $02AE,
   U1BRGL as byte absolute $02AE,
   U1BRGH as byte absolute $02AF,
   U1FIFO as byte absolute $02B0,
   U1UIR as byte absolute $02B1,
   U1ERRIR as byte absolute $02B2,
   U1ERRIE as byte absolute $02B3,
   U2RXB as byte absolute $02B4,
   U2RXBL as byte absolute $02B4,
   U2RXCHK as byte absolute $02B5,
   U2TXB as byte absolute $02B6,
   U2TXBL as byte absolute $02B6,
   U2TXCHK as byte absolute $02B7,
   U2P1 as byte absolute $02B8,
   U2P1L as byte absolute $02B8,
   U2P1H as byte absolute $02B9,
   U2P2 as byte absolute $02BA,
   U2P2L as byte absolute $02BA,
   U2P2H as byte absolute $02BB,
   U2P3 as byte absolute $02BC,
   U2P3L as byte absolute $02BC,
   U2P3H as byte absolute $02BD,
   U2CON0 as byte absolute $02BE,
   U2CON1 as byte absolute $02BF,
   U2CON2 as byte absolute $02C0,
   U2BRG as byte absolute $02C1,
   U2BRGL as byte absolute $02C1,
   U2BRGH as byte absolute $02C2,
   U2FIFO as byte absolute $02C3,
   U2UIR as byte absolute $02C4,
   U2ERRIR as byte absolute $02C5,
   U2ERRIE as byte absolute $02C6,
   U3RXB as byte absolute $02C7,
   U3RXBL as byte absolute $02C7,
   U3TXB as byte absolute $02C9,
   U3TXBL as byte absolute $02C9,
   U3P1 as byte absolute $02CB,
   U3P1L as byte absolute $02CB,
   U3P2 as byte absolute $02CD,
   U3P2L as byte absolute $02CD,
   U3P3 as byte absolute $02CF,
   U3P3L as byte absolute $02CF,
   U3CON0 as byte absolute $02D1,
   U3CON1 as byte absolute $02D2,
   U3CON2 as byte absolute $02D3,
   U3BRG as byte absolute $02D4,
   U3BRGL as byte absolute $02D4,
   U3BRGH as byte absolute $02D5,
   U3FIFO as byte absolute $02D6,
   U3UIR as byte absolute $02D7,
   U3ERRIR as byte absolute $02D8,
   U3ERRIE as byte absolute $02D9,
   U4RXB as byte absolute $02DA,
   U4RXBL as byte absolute $02DA,
   U4TXB as byte absolute $02DC,
   U4TXBL as byte absolute $02DC,
   U4P1 as byte absolute $02DE,
   U4P1L as byte absolute $02DE,
   U4P2 as byte absolute $02E0,
   U4P2L as byte absolute $02E0,
   U4P3 as byte absolute $02E2,
   U4P3L as byte absolute $02E2,
   U4CON0 as byte absolute $02E4,
   U4CON1 as byte absolute $02E5,
   U4CON2 as byte absolute $02E6,
   U4BRG as byte absolute $02E7,
   U4BRGL as byte absolute $02E7,
   U4BRGH as byte absolute $02E8,
   U4FIFO as byte absolute $02E9,
   U4UIR as byte absolute $02EA,
   U4ERRIR as byte absolute $02EB,
   U4ERRIE as byte absolute $02EC,
   U5RXB as byte absolute $02ED,
   U5RXBL as byte absolute $02ED,
   U5TXB as byte absolute $02EF,
   U5TXBL as byte absolute $02EF,
   U5P1 as byte absolute $02F1,
   U5P1L as byte absolute $02F1,
   U5P2 as byte absolute $02F3,
   U5P2L as byte absolute $02F3,
   U5P3 as byte absolute $02F5,
   U5P3L as byte absolute $02F5,
   U5CON0 as byte absolute $02F7,
   U5CON1 as byte absolute $02F8,
   U5CON2 as byte absolute $02F9,
   U5BRG as byte absolute $02FA,
   U5BRGL as byte absolute $02FA,
   U5BRGH as byte absolute $02FB,
   U5FIFO as byte absolute $02FC,
   U5UIR as byte absolute $02FD,
   U5ERRIR as byte absolute $02FE,
   U5ERRIE as byte absolute $02FF,
   SMT1TMR as byte absolute $0300,
   SMT1TMRL as byte absolute $0300,
   SMT1TMRH as byte absolute $0301,
   SMT1TMRU as byte absolute $0302,
   SMT1CPR as byte absolute $0303,
   SMT1CPRL as byte absolute $0303,
   SMT1CPRH as byte absolute $0304,
   SMT1CPRU as byte absolute $0305,
   SMT1CPW as byte absolute $0306,
   SMT1CPWL as byte absolute $0306,
   SMT1CPWH as byte absolute $0307,
   SMT1CPWU as byte absolute $0308,
   SMT1PR as byte absolute $0309,
   SMT1PRL as byte absolute $0309,
   SMT1PRH as byte absolute $030A,
   SMT1PRU as byte absolute $030B,
   SMT1CON0 as byte absolute $030C,
   SMT1CON1 as byte absolute $030D,
   SMT1STAT as byte absolute $030E,
   SMT1CLK as byte absolute $030F,
   SMT1SIG as byte absolute $0310,
   SMT1WIN as byte absolute $0311,
   TMR0 as byte absolute $0318,
   TMR0L as byte absolute $0318,
   PR0 as byte absolute $0319,
   TMR0H as byte absolute $0319,
   T0CON0 as byte absolute $031A,
   T0CON1 as byte absolute $031B,
   TMR1L as byte absolute $031C,
   TMR1H as byte absolute $031D,
   T1CON as byte absolute $031E,
   TMR1CON as byte absolute $031E,
   T1GCON as byte absolute $031F,
   TMR1GCON as byte absolute $031F,
   T1GATE as byte absolute $0320,
   TMR1GATE as byte absolute $0320,
   T1CLK as byte absolute $0321,
   TMR1CLK as byte absolute $0321,
   T2TMR as byte absolute $0322,
   TMR2 as byte absolute $0322,
   PR2 as byte absolute $0323,
   T2PR as byte absolute $0323,
   T2CON as byte absolute $0324,
   T2HLT as byte absolute $0325,
   T2CLK as byte absolute $0326,
   T2CLKCON as byte absolute $0326,
   T2RST as byte absolute $0327,
   TMR3L as byte absolute $0328,
   TMR3H as byte absolute $0329,
   T3CON as byte absolute $032A,
   TMR3CON as byte absolute $032A,
   T3GCON as byte absolute $032B,
   TMR3GCON as byte absolute $032B,
   T3GATE as byte absolute $032C,
   TMR3GATE as byte absolute $032C,
   T3CLK as byte absolute $032D,
   TMR3CLK as byte absolute $032D,
   T4TMR as byte absolute $032E,
   TMR4 as byte absolute $032E,
   PR4 as byte absolute $032F,
   T4PR as byte absolute $032F,
   T4CON as byte absolute $0330,
   T4HLT as byte absolute $0331,
   T4CLK as byte absolute $0332,
   T4CLKCON as byte absolute $0332,
   T4RST as byte absolute $0333,
   TMR5L as byte absolute $0334,
   TMR5H as byte absolute $0335,
   T5CON as byte absolute $0336,
   TMR5CON as byte absolute $0336,
   T5GCON as byte absolute $0337,
   TMR5GCON as byte absolute $0337,
   T5GATE as byte absolute $0338,
   TMR5GATE as byte absolute $0338,
   T5CLK as byte absolute $0339,
   TMR5CLK as byte absolute $0339,
   T6TMR as byte absolute $033A,
   TMR6 as byte absolute $033A,
   PR6 as byte absolute $033B,
   T6PR as byte absolute $033B,
   T6CON as byte absolute $033C,
   T6HLT as byte absolute $033D,
   T6CLK as byte absolute $033E,
   T6CLKCON as byte absolute $033E,
   T6RST as byte absolute $033F,
   CCPR1 as byte absolute $0340,
   CCPR1L as byte absolute $0340,
   CCPR1H as byte absolute $0341,
   CCP1CON as byte absolute $0342,
   CCP1CAP as byte absolute $0343,
   CCPR2 as byte absolute $0344,
   CCPR2L as byte absolute $0344,
   CCPR2H as byte absolute $0345,
   CCP2CON as byte absolute $0346,
   CCP2CAP as byte absolute $0347,
   CCPR3 as byte absolute $0348,
   CCPR3L as byte absolute $0348,
   CCPR3H as byte absolute $0349,
   CCP3CON as byte absolute $034A,
   CCP3CAP as byte absolute $034B,
   CCPTMRS0 as byte absolute $034C,
   CRCDATA as byte absolute $034F,
   CRCDATAL as byte absolute $034F,
   CRCDATAH as byte absolute $0350,
   CRCDATAU as byte absolute $0351,
   CRCDATAT as byte absolute $0352,
   CRCOUT as byte absolute $0353,
   CRCOUTL as byte absolute $0353,
   CRCSHFT as byte absolute $0353,
   CRCSHFTL as byte absolute $0353,
   CRCXOR as byte absolute $0353,
   CRCXORL as byte absolute $0353,
   CRCOUTH as byte absolute $0354,
   CRCSHFTH as byte absolute $0354,
   CRCXORH as byte absolute $0354,
   CRCOUTU as byte absolute $0355,
   CRCSHFTU as byte absolute $0355,
   CRCXORU as byte absolute $0355,
   CRCOUTT as byte absolute $0356,
   CRCSHFTT as byte absolute $0356,
   CRCXORT as byte absolute $0356,
   CRCCON0 as byte absolute $0357,
   CRCCON1 as byte absolute $0358,
   CRCCON2 as byte absolute $0359,
   SCANLADR as byte absolute $035A,
   SCANLADRL as byte absolute $035A,
   SCANLADRH as byte absolute $035B,
   SCANLADRU as byte absolute $035C,
   SCANHADR as byte absolute $035D,
   SCANHADRL as byte absolute $035D,
   SCANHADRH as byte absolute $035E,
   SCANHADRU as byte absolute $035F,
   SCANCON0 as byte absolute $0360,
   SCANTRIG as byte absolute $0361,
   IPR0 as byte absolute $0362,
   IPR1 as byte absolute $0363,
   IPR2 as byte absolute $0364,
   IPR3 as byte absolute $0365,
   IPR4 as byte absolute $0366,
   IPR5 as byte absolute $0367,
   IPR6 as byte absolute $0368,
   IPR7 as byte absolute $0369,
   IPR8 as byte absolute $036A,
   IPR9 as byte absolute $036B,
   IPR10 as byte absolute $036C,
   IPR11 as byte absolute $036D,
   IPR12 as byte absolute $036E,
   IPR13 as byte absolute $036F,
   IPR14 as byte absolute $0370,
   IPR15 as byte absolute $0371,
   STATUS_CSHAD as byte absolute $0373,
   WREG_CSHAD as byte absolute $0374,
   BSR_CSHAD as byte absolute $0375,
   SHADCON as byte absolute $0376,
   STATUS_SHAD as byte absolute $0377,
   WREG_SHAD as byte absolute $0378,
   BSR_SHAD as byte absolute $0379,
   PCLATH_SHAD as byte absolute $037A,
   PCLATU_SHAD as byte absolute $037B,
   FSR0L_SHAD as byte absolute $037C,
   FSR0SH as byte absolute $037C,
   FSR0H_SHAD as byte absolute $037D,
   FSR1L_SHAD as byte absolute $037E,
   FSR1SH as byte absolute $037E,
   FSR1H_SHAD as byte absolute $037F,
   FSR2L_SHAD as byte absolute $0380,
   FSR2SH as byte absolute $0380,
   FSR2H_SHAD as byte absolute $0381,
   PRODL_SHAD as byte absolute $0382,
   PRODSH as byte absolute $0382,
   PRODH_SHAD as byte absolute $0383,
   TU16ACON0 as byte absolute $0387,
   TU16ACON1 as byte absolute $0388,
   TU16AHLT as byte absolute $0389,
   TU16APS as byte absolute $038A,
   TU16ACR as byte absolute $038B,
   TU16ACRL as byte absolute $038B,
   TU16ATMR as byte absolute $038B,
   TU16ATMRL as byte absolute $038B,
   TU16ACRH as byte absolute $038C,
   TU16ATMRH as byte absolute $038C,
   TU16APR as byte absolute $038D,
   TU16APRL as byte absolute $038D,
   TU16APRH as byte absolute $038E,
   TU16ACLK as byte absolute $038F,
   TU16AERS as byte absolute $0390,
   TU16BCON0 as byte absolute $0393,
   TU16BCON1 as byte absolute $0394,
   TU16BHLT as byte absolute $0395,
   TU16BPS as byte absolute $0396,
   TU16BCR as byte absolute $0397,
   TU16BCRL as byte absolute $0397,
   TU16BTMR as byte absolute $0397,
   TU16BTMRL as byte absolute $0397,
   TU16BCRH as byte absolute $0398,
   TU16BTMRH as byte absolute $0398,
   TU16BPR as byte absolute $0399,
   TU16BPRL as byte absolute $0399,
   TU16BPRH as byte absolute $039A,
   TU16BCLK as byte absolute $039B,
   TU16BERS as byte absolute $039C,
   TUCHAIN as byte absolute $03BB,
   CWG1CLK as byte absolute $03BC,
   CWG1CLKCON as byte absolute $03BC,
   CWG1ISM as byte absolute $03BD,
   CWG1DBR as byte absolute $03BE,
   CWG1DBF as byte absolute $03BF,
   CWG1CON0 as byte absolute $03C0,
   CWG1CON1 as byte absolute $03C1,
   CWG1AS0 as byte absolute $03C2,
   CWG1AS1 as byte absolute $03C3,
   CWG1STR as byte absolute $03C4,
   CWG2CLK as byte absolute $03C5,
   CWG2CLKCON as byte absolute $03C5,
   CWG2ISM as byte absolute $03C6,
   CWG2DBR as byte absolute $03C7,
   CWG2DBF as byte absolute $03C8,
   CWG2CON0 as byte absolute $03C9,
   CWG2CON1 as byte absolute $03CA,
   CWG2AS0 as byte absolute $03CB,
   CWG2AS1 as byte absolute $03CC,
   CWG2STR as byte absolute $03CD,
   CWG3CLK as byte absolute $03CE,
   CWG3CLKCON as byte absolute $03CE,
   CWG3ISM as byte absolute $03CF,
   CWG3DBR as byte absolute $03D0,
   CWG3DBF as byte absolute $03D1,
   CWG3CON0 as byte absolute $03D2,
   CWG3CON1 as byte absolute $03D3,
   CWG3AS0 as byte absolute $03D4,
   CWG3AS1 as byte absolute $03D5,
   CWG3STR as byte absolute $03D6,
   FVRCON as byte absolute $03D7,
   ADCP as byte absolute $03D8,
   ADCPCON as byte absolute $03D8,
   ADLTH as byte absolute $03D9,
   ADLTHL as byte absolute $03D9,
   ADLTHH as byte absolute $03DA,
   ADUTH as byte absolute $03DB,
   ADUTHL as byte absolute $03DB,
   ADUTHH as byte absolute $03DC,
   ADERR as byte absolute $03DD,
   ADERRL as byte absolute $03DD,
   ADERRH as byte absolute $03DE,
   ADSTPT as byte absolute $03DF,
   ADSTPTL as byte absolute $03DF,
   ADSTPTH as byte absolute $03E0,
   ADFLTR as byte absolute $03E1,
   ADFLTRL as byte absolute $03E1,
   ADFLTRH as byte absolute $03E2,
   ADACC as byte absolute $03E3,
   ADACCL as byte absolute $03E3,
   ADACCH as byte absolute $03E4,
   ADACCU as byte absolute $03E5,
   ADCNT as byte absolute $03E6,
   ADRPT as byte absolute $03E7,
   ADPREV as byte absolute $03E8,
   ADPREVL as byte absolute $03E8,
   ADPREVH as byte absolute $03E9,
   ADRES as byte absolute $03EA,
   ADRESL as byte absolute $03EA,
   ADRESH as byte absolute $03EB,
   ADPCH as byte absolute $03EC,
   ADACQ as byte absolute $03EE,
   ADACQL as byte absolute $03EE,
   ADACQH as byte absolute $03EF,
   ADCAP as byte absolute $03F0,
   ADPRE as byte absolute $03F1,
   ADPREL as byte absolute $03F1,
   ADPREH as byte absolute $03F2,
   ADCON0 as byte absolute $03F3,
   ADCON1 as byte absolute $03F4,
   ADCON2 as byte absolute $03F5,
   ADCON3 as byte absolute $03F6,
   ADSTAT as byte absolute $03F7,
   ADREF as byte absolute $03F8,
   ADACT as byte absolute $03F9,
   ADCLK as byte absolute $03FA,
   ADCTX as byte absolute $03FB,
   ADCSEL1 as byte absolute $03FC,
   ADCSEL2 as byte absolute $03FD,
   ADCSEL3 as byte absolute $03FE,
   ADCSEL4 as byte absolute $03FF,
   ANSELA as byte absolute $0400,
   WPUA as byte absolute $0401,
   ODCONA as byte absolute $0402,
   SLRCONA as byte absolute $0403,
   INLVLA as byte absolute $0404,
   IOCAP as byte absolute $0405,
   IOCAN as byte absolute $0406,
   IOCAF as byte absolute $0407,
   ANSELB as byte absolute $0408,
   WPUB as byte absolute $0409,
   ODCONB as byte absolute $040A,
   SLRCONB as byte absolute $040B,
   INLVLB as byte absolute $040C,
   IOCBP as byte absolute $040D,
   IOCBN as byte absolute $040E,
   IOCBF as byte absolute $040F,
   ANSELC as byte absolute $0410,
   WPUC as byte absolute $0411,
   ODCONC as byte absolute $0412,
   SLRCONC as byte absolute $0413,
   INLVLC as byte absolute $0414,
   IOCCP as byte absolute $0415,
   IOCCN as byte absolute $0416,
   IOCCF as byte absolute $0417,
   WPUE as byte absolute $0421,
   INLVLE as byte absolute $0424,
   IOCEP as byte absolute $0425,
   IOCEN as byte absolute $0426,
   IOCEF as byte absolute $0427,
   NCO1ACC as byte absolute $0440,
   NCO1ACCL as byte absolute $0440,
   NCO1ACCH as byte absolute $0441,
   NCO1ACCU as byte absolute $0442,
   NCO1INC as byte absolute $0443,
   NCO1INCL as byte absolute $0443,
   NCO1INCH as byte absolute $0444,
   NCO1INCU as byte absolute $0445,
   NCO1CON as byte absolute $0446,
   NCO1CLK as byte absolute $0447,
   NCO2ACC as byte absolute $0448,
   NCO2ACCL as byte absolute $0448,
   NCO2ACCH as byte absolute $0449,
   NCO2ACCU as byte absolute $044A,
   NCO2INC as byte absolute $044B,
   NCO2INCL as byte absolute $044B,
   NCO2INCH as byte absolute $044C,
   NCO2INCU as byte absolute $044D,
   NCO2CON as byte absolute $044E,
   NCO2CLK as byte absolute $044F,
   NCO3ACC as byte absolute $0450,
   NCO3ACCL as byte absolute $0450,
   NCO3ACCH as byte absolute $0451,
   NCO3ACCU as byte absolute $0452,
   NCO3INC as byte absolute $0453,
   NCO3INCL as byte absolute $0453,
   NCO3INCH as byte absolute $0454,
   NCO3INCU as byte absolute $0455,
   NCO3CON as byte absolute $0456,
   NCO3CLK as byte absolute $0457,
   FSCMCON as byte absolute $0458,
   IVTLOCK as byte absolute $0459,
   IVTAD as byte absolute $045A,
   IVTADL as byte absolute $045A,
   IVTADH as byte absolute $045B,
   IVTADU as byte absolute $045C,
   IVTBASE as byte absolute $045D,
   IVTBASEL as byte absolute $045D,
   IVTBASEH as byte absolute $045E,
   IVTBASEU as byte absolute $045F,
   PWM1ERS as byte absolute $0460,
   PWM1CLK as byte absolute $0461,
   PWM1LDS as byte absolute $0462,
   PWM1PR as byte absolute $0463,
   PWM1PRL as byte absolute $0463,
   PWM1PRH as byte absolute $0464,
   PWM1CPRE as byte absolute $0465,
   PWM1PIPOS as byte absolute $0466,
   PWM1GIR as byte absolute $0467,
   PWM1GIE as byte absolute $0468,
   PWM1CON as byte absolute $0469,
   PWM1S1CFG as byte absolute $046A,
   PWM1S1P1 as byte absolute $046B,
   PWM1S1P1L as byte absolute $046B,
   PWM1S1P1H as byte absolute $046C,
   PWM1S1P2 as byte absolute $046D,
   PWM1S1P2L as byte absolute $046D,
   PWM1S1P2H as byte absolute $046E,
   PWM2ERS as byte absolute $046F,
   PWM2CLK as byte absolute $0470,
   PWM2LDS as byte absolute $0471,
   PWM2PR as byte absolute $0472,
   PWM2PRL as byte absolute $0472,
   PWM2PRH as byte absolute $0473,
   PWM2CPRE as byte absolute $0474,
   PWM2PIPOS as byte absolute $0475,
   PWM2GIR as byte absolute $0476,
   PWM2GIE as byte absolute $0477,
   PWM2CON as byte absolute $0478,
   PWM2S1CFG as byte absolute $0479,
   PWM2S1P1 as byte absolute $047A,
   PWM2S1P1L as byte absolute $047A,
   PWM2S1P1H as byte absolute $047B,
   PWM2S1P2 as byte absolute $047C,
   PWM2S1P2L as byte absolute $047C,
   PWM2S1P2H as byte absolute $047D,
   PWM3ERS as byte absolute $047E,
   PWM3CLK as byte absolute $047F,
   PWM3LDS as byte absolute $0480,
   PWM3PR as byte absolute $0481,
   PWM3PRL as byte absolute $0481,
   PWM3PRH as byte absolute $0482,
   PWM3CPRE as byte absolute $0483,
   PWM3PIPOS as byte absolute $0484,
   PWM3GIR as byte absolute $0485,
   PWM3GIE as byte absolute $0486,
   PWM3CON as byte absolute $0487,
   PWM3S1CFG as byte absolute $0488,
   PWM3S1P1 as byte absolute $0489,
   PWM3S1P1L as byte absolute $0489,
   PWM3S1P1H as byte absolute $048A,
   PWM3S1P2 as byte absolute $048B,
   PWM3S1P2L as byte absolute $048B,
   PWM3S1P2H as byte absolute $048C,
   PWM4ERS as byte absolute $048D,
   PWM4CLK as byte absolute $048E,
   PWM4LDS as byte absolute $048F,
   PWM4PR as byte absolute $0490,
   PWM4PRL as byte absolute $0490,
   PWM4PRH as byte absolute $0491,
   PWM4CPRE as byte absolute $0492,
   PWM4PIPOS as byte absolute $0493,
   PWM4GIR as byte absolute $0494,
   PWM4GIE as byte absolute $0495,
   PWM4CON as byte absolute $0496,
   PWM4S1CFG as byte absolute $0497,
   PWM4S1P1 as byte absolute $0498,
   PWM4S1P1L as byte absolute $0498,
   PWM4S1P1H as byte absolute $0499,
   PWM4S1P2 as byte absolute $049A,
   PWM4S1P2L as byte absolute $049A,
   PWM4S1P2H as byte absolute $049B,
   PWMLOAD as byte absolute $049C,
   PWMEN as byte absolute $049D,
   PIE0 as byte absolute $049E,
   PIE1 as byte absolute $049F,
   PIE2 as byte absolute $04A0,
   PIE3 as byte absolute $04A1,
   PIE4 as byte absolute $04A2,
   PIE5 as byte absolute $04A3,
   PIE6 as byte absolute $04A4,
   PIE7 as byte absolute $04A5,
   PIE8 as byte absolute $04A6,
   PIE9 as byte absolute $04A7,
   PIE10 as byte absolute $04A8,
   PIE11 as byte absolute $04A9,
   PIE12 as byte absolute $04AA,
   PIE13 as byte absolute $04AB,
   PIE14 as byte absolute $04AC,
   PIE15 as byte absolute $04AD,
   PIR0 as byte absolute $04AE,
   PIR1 as byte absolute $04AF,
   PIR2 as byte absolute $04B0,
   PIR3 as byte absolute $04B1,
   PIR4 as byte absolute $04B2,
   PIR5 as byte absolute $04B3,
   PIR6 as byte absolute $04B4,
   PIR7 as byte absolute $04B5,
   PIR8 as byte absolute $04B6,
   PIR9 as byte absolute $04B7,
   PIR10 as byte absolute $04B8,
   PIR11 as byte absolute $04B9,
   PIR12 as byte absolute $04BA,
   PIR13 as byte absolute $04BB,
   PIR14 as byte absolute $04BC,
   PIR15 as byte absolute $04BD,
   LATA as byte absolute $04BE,
   LATB as byte absolute $04BF,
   LATC as byte absolute $04C0,
   TRISA as byte absolute $04C6,
   TRISB as byte absolute $04C7,
   TRISC as byte absolute $04C8,
   TRISE as byte absolute $04CA,
   INTCON as byte absolute $04D6,
   INTCON0 as byte absolute $04D6,
   INTCON1 as byte absolute $04D7,
   STATUS as byte absolute $04D8,
   FSR2L as byte absolute $04D9,
   FSR2H as byte absolute $04DA,
   PLUSW2 as byte absolute $04DB,
   PREINC2 as byte absolute $04DC,
   POSTDEC2 as byte absolute $04DD,
   POSTINC2 as byte absolute $04DE,
   INDF2 as byte absolute $04DF,
   BSR as byte absolute $04E0,
   FSR1L as byte absolute $04E1,
   FSR1H as byte absolute $04E2,
   PLUSW1 as byte absolute $04E3,
   PREINC1 as byte absolute $04E4,
   POSTDEC1 as byte absolute $04E5,
   POSTINC1 as byte absolute $04E6,
   INDF1 as byte absolute $04E7,
   WREG as byte absolute $04E8,
   FSR0L as byte absolute $04E9,
   FSR0H as byte absolute $04EA,
   PLUSW0 as byte absolute $04EB,
   PREINC0 as byte absolute $04EC,
   POSTDEC0 as byte absolute $04ED,
   POSTINC0 as byte absolute $04EE,
   INDF0 as byte absolute $04EF,
   PCON0 as byte absolute $04F0,
   PCON1 as byte absolute $04F1,
   CPUDOZE as byte absolute $04F2,
   PRODL as byte absolute $04F3,
   PRODH as byte absolute $04F4,
   TABLAT as byte absolute $04F5,
   TBLPTR as byte absolute $04F6,
   TBLPTRL as byte absolute $04F6,
   TBLPTRH as byte absolute $04F7,
   TBLPTRU as byte absolute $04F8,
   PC as byte absolute $04F9,
   PCL as byte absolute $04F9,
   PCLATH as byte absolute $04FA,
   PCLATU as byte absolute $04FB,
   STKPTR as byte absolute $04FC,
   TOS as byte absolute $04FD,
   TOSL as byte absolute $04FD,
   TOSH as byte absolute $04FE,
   TOSU as byte absolute $04FF

// system ports...
public system port
   PORTA as byte absolute $04CE,
   PORTB as byte absolute $04CF,
   PORTC as byte absolute $04D0,
   PORTE as byte absolute $04D2

// interrupt priority...
public dim
   IPEN as INTCON0.bits(5)

// sfr alias...
public dim
   PROD as PRODL.AsWord,
   FSR0 as FSR0L.AsWord,
   FSR1 as FSR1L.AsWord,
   FSR2 as FSR2L.AsWord,
   TABLEPTR as TBLPTRL.AsWord
public dim
   PRODW as word absolute $04F3,
   FSR0W as word absolute $04E9,
   FSR1W as word absolute $04E1,
   FSR2W as word absolute $04D9,
   TABLEPTRW as word absolute $04F6

// configuration fuses...
public config
   FEXTOSC(FEXTOSC) = [LP, XT, HS, OFF, ECL, ECM, ECH],
   RSTOSC(RSTOSC) = [HFINTOSC_64MHZ, RESERVED_1, EXTOSC_4PLL, RESERVED_2, SOSC, LFINTOSC, HFINTOSC_1MHZ, EXTOSC],
   CLKOUTEN(CLKOUTEN) = [ON, OFF],
   PR1WAY(PR1WAY) = [OFF, ON],
   CSWEN(CSWEN) = [OFF, ON],
   JTAGEN(JTAGEN) = [OFF, ON],
   FCMEN(FCMEN) = [OFF, ON],
   FCMENP(FCMENP) = [OFF, ON],
   FCMENS(FCMENS) = [OFF, ON],
   MCLRE(MCLRE) = [INTMCLR, EXTMCLR],
   PWRTS(PWRTS) = [PWRT_1, PWRT_16, PWRT_64, PWRT_OFF],
   MVECEN(MVECEN) = [OFF, ON],
   IVT1WAY(IVT1WAY) = [OFF, ON],
   LPBOREN(LPBOREN) = [ON, OFF],
   BOREN(BOREN) = [OFF, ON, NOSLP, SBORDIS],
   BORV(BORV) = [VBOR_2P85, VBOR_2P7, VBOR_2P45, VBOR_1P9],
   ZCD(ZCD) = [ON, OFF],
   PPS1WAY(PPS1WAY) = [OFF, ON],
   STVREN(STVREN) = [OFF, ON],
   LVP(LVP) = [OFF, ON],
   XINST(XINST) = [ON, OFF],
   WDTCPS(WDTCPS) = [WDTCPS_0, WDTCPS_1, WDTCPS_2, WDTCPS_3, WDTCPS_4, WDTCPS_5, WDTCPS_6, WDTCPS_7, WDTCPS_8, WDTCPS_9, WDTCPS_10, WDTCPS_11, WDTCPS_12, WDTCPS_13, WDTCPS_14, WDTCPS_15, WDTCPS_16, WDTCPS_17, WDTCPS_18, WDTCPS_19, WDTCPS_20, WDTCPS_21, WDTCPS_22, WDTCPS_23, WDTCPS_24, WDTCPS_25, WDTCPS_26, WDTCPS_27, WDTCPS_28, WDTCPS_29, WDTCPS_30, WDTCPS_31],
   WDTE(WDTE) = [OFF, SWDTEN, NSLEEP, ON],
   WDTCWS(WDTCWS) = [WDTCWS_0, WDTCWS_1, WDTCWS_2, WDTCWS_3, WDTCWS_4, WDTCWS_5, WDTCWS_6, WDTCWS_7],
   WDTCCS(WDTCCS) = [LFINTOSC, MFINTOSC, SOSC, SC],
   BBSIZE(BBSIZE) = [BBSIZE_32768, BBSIZE_16384, BBSIZE_8192, BBSIZE_4096, BBSIZE_2048, BBSIZE_1024, BBSIZE_512],
   BBEN(BBEN) = [ON, OFF],
   SAFEN(SAFEN) = [ON, OFF],
   WRTB(WRTB) = [ON, OFF],
   WRTC(WRTC) = [ON, OFF],
   WRTD(WRTD) = [ON, OFF],
   WRTSAF(WRTSAF) = [ON, OFF],
   WRTAPP(WRTAPP) = [ON, OFF],
   BOOTPINSEL(BOOTPINSEL) = [RA4, RA2, RC4, RC5],
   BPEN(BPEN) = [ON, OFF],
   ODCON(ODCON) = [ON, OFF],
   CP(CP) = [ON, OFF]

//
// extended config words $30000a-$300022 are treated as a special case since 
// mpasmx can't handle more than 16 bytes of config data 
// these are used by the library file config_Q84.bas to insert bytes directly 
// into the hex file... see that file for details and example usage
//
// CONFIG11 $30000a (CRC_CONFIG) bit setting definitions
//  'and' the desired values together and assign it to '#variable CRC_CONFIG'
//  example: #variable CRC_CONFIG = BOOTSCEN and CFGSCEN and BOOTPOR
#const BOOTSCEN = not($01)      // CRC on boot scan enable for boot area
#const BOOTCOE  = not($02)      // CRC on boot Continue on Error for boot areas bit
#const APPSCEN  = not($04)      // CRC on boot application code scan enable
#const SAFSCEN  = not($08)      // CRC on boot SAF area scan enable
#const DATASCEN = not($10)      // CRC on boot Data EEPROM scan enable
#const CFGSCEN  = not($20)      // CRC on boot Config fuses scan enable
#const COE      = not($40)      // CRC on boot Continue on Error for non-boot areas bit
#const BOOTPOR  = not($80)      // Boot on CRC Enable bit

// default extended config data... you can override these in your main project file
// all registers except CRC_CONFIG accept byte values = $00 to $FF
#variable CRC_CONFIG = $FF      // $30000a (have to start on an even address)
#variable BCRCPOLT  = $FF
#variable BCRCPOLU  = $FF
#variable BCRCPOLH  = $FF
#variable BCRCPOLL  = $FF
#variable BCRCSEEDT = $FF
#variable BCRCSEEDU = $FF
#variable BCRCSEEDH = $FF
#variable BCRCSEEDL = $FF
#variable BCRCEREST = $FF
#variable BCRCERESU = $FF
#variable BCRCERESH = $FF
#variable BCRCERESL = $FF
#variable CRCPOLT   = $FF
#variable CRCPOLU   = $FF
#variable CRCPOLH   = $FF
#variable CRCPOLL   = $FF
#variable CRCSEEDT  = $FF
#variable CRCSEEDU  = $FF
#variable CRCSEEDH  = $FF
#variable CRCSEEDL  = $FF
#variable CRCEREST  = $FF
#variable CRCERESU  = $FF
#variable CRCERESH  = $FF
#variable CRCERESL  = $FF

// default fuses...
config
   FEXTOSC = HS,
   RSTOSC = HFINTOSC_64MHZ,
   FCMEN = OFF,
   JTAGEN = OFF,
   PR1WAY = OFF,
   MVECEN = OFF,
   BOREN = ON,
   STVREN = ON,
   XINST = OFF,
   LVP = OFF,
   PPS1WAY = OFF,
   WDTE = OFF

end module
